[−][src]Struct web_push::WebPushPayload
The push content payload, already in an encrypted form.
Fields
content: Vec<u8>Encrypted content data.
crypto_headers: Vec<(&'static str, String)>Headers depending on the authorization scheme and encryption standard.
content_encoding: &'static strThe encryption standard.