[−][src]Enum web_push::WebPushError
Variants
UnspecifiedAn unknown error happened encrypting the message,
Please provide valid credentials to send the notification
BadRequest(Option<String>)Request was badly formed
ServerError(Option<Duration>)Contains an optional Duration, until the user can retry the request
NotImplementedThe feature is not implemented yet
InvalidUriThe provided URI is invalid
TimeoutErrorThe request timed out
EndpointNotValidThe URL specified is no longer valid and should no longer be used
EndpointNotFoundThe URL specified is invalid and should not be used again
PayloadTooLargeMaximum allowed payload size is 3800 characters
TlsErrorCould not initialize a TLS connection
SslErrorError in SSL signing
IoErrorError in reading a file
InvalidPackageNameMake sure the message was addressed to a registration token whose package name matches the value passed in the request (Google).
InvalidTtlThe TTL value provided was not valid or was not provided
MissingCryptoKeysThe request was missing required crypto keys
InvalidCryptoKeysOne or more of the crypto key elements are invalid.
InvalidResponseCorrupted response data
Other(String)Methods
impl WebPushError[src]
pub fn short_description(&self) -> &'static str[src]