Struct web_push::WebPushMessageBuilder [] [src]

pub struct WebPushMessageBuilder<'a> { /* fields omitted */ }

Methods

impl<'a> WebPushMessageBuilder<'a>
[src]

Creates a builder for generating the web push payload.

All parameters are from the subscription info given by browser when subscribing to push notifications.

How long the server should keep the message if it cannot be delivered currently. If not set, the message is deleted immediately on failed delivery.

For Google's push service, one must provide an API key from Firebase console.

If set, the client will get content in the notification. Has a maximum size of 3800 characters.

Builds and if set, encrypts the payload. Any errors will be Undefined, meaning something was wrong in the given public key or authentication.